import os


def generate_media_serial(media_dirs=["."]):
    """
    Generates a media serial number that can be appended to a media filename
    in order to make a URL that can be cached forever without fear of change.
    The next time the file is updated and the server is restarted, a new
    path will be accessed and cached.

    This will crawl the media files (using directories passed to this
    function, or all of MEDIA_ROOT otherwise), figuring out the latest
    timestamp, and return that value.
    """
    MEDIA_SERIAL = 0

    for media_dir in media_dirs:
        media_path = os.path.join(settings.MEDIA_ROOT, media_dir)

        for root, dirs, files in os.walk(media_path):
            for name in files:
                mtime = int(os.stat(os.path.join(root, name)).st_mtime)

                if mtime > MEDIA_SERIAL:
                    MEDIA_SERIAL = mtime

    return MEDIA_SERIAL


def generate_ajax_serial(template_dirs=["."]):
    """
    Generates a serial number that can be appended to filenames involving
    dynamic loads of URLs in order to make a URL that can be cached forever
    without fear of change.

    This will crawl the template files (using directories passed to this
    function), figuring out the latest timestamp, and return that value.
    """
    AJAX_SERIAL = 0

    for template_path in template_dirs:
        for root, dirs, files in os.walk(template_path):
            for name in files:
                mtime = int(os.stat(os.path.join(root, name)).st_mtime)

                if mtime > AJAX_SERIAL:
                    AJAX_SERIAL = mtime

    return AJAX_SERIAL
